package com.ruoyi.sensor.service.impl;

import com.ruoyi.board.domain.AlertPlan;
import com.ruoyi.board.domain.BoardInfo;
import com.ruoyi.board.domain.PresetContent;
import com.ruoyi.board.domain.ReleaseRecord;
import com.ruoyi.board.domain.enums.AlertPlanType;
import com.ruoyi.board.service.IAlertPlanService;
import com.ruoyi.board.service.IBoardInfoService;
import com.ruoyi.board.service.IPresetContentService;
import com.ruoyi.board.service.IReleaseRecordService;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.protocol.sansi.SanSiProtocol;
import com.ruoyi.sensor.domain.PerceptionParams;
import com.ruoyi.sensor.domain.WarningStatusInfo;
import com.ruoyi.sensor.merchants.MerchantsHttp;
import com.ruoyi.sensor.service.ISensorDataService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service
public class SensorDataServiceImpl implements ISensorDataService {

    private static final Logger log = LoggerFactory.getLogger(SensorDataServiceImpl.class);
    @Autowired
    private IBoardInfoService boardInfoService;
    @Autowired
    private IAlertPlanService alertPlanService;
    @Autowired
    private IPresetContentService presetContentService;
    @Autowired
    private IReleaseRecordService releaseRecordService;

    @Override
    public void perceptionParamsHandler(PerceptionParams params) {
        int planTypeByName = AlertPlanType.getPlanTypeByName(params.getPerceptionType());
        // 找到符合计划的预警
        AlertPlan oneByTypeAndValue = alertPlanService.getOneByTypeAndValue(planTypeByName, params.getPerceptionValue());
        if (null == oneByTypeAndValue) {
            log.error("找不到预警计划");
            return;
        }
        // 情报板设备信息
        BoardInfo oneByIP = boardInfoService.getOneByIP(params.getBoardIp());
        if (null == oneByIP) {
            log.error("找不到情报板信息");
            return;
        }
        // 预置发布的信息
        PresetContent oneByContentAndBoardSize = presetContentService.getOneByContentAndBoardSize(oneByTypeAndValue.getDisplayContent(), oneByIP.getBoardSize(), planTypeByName);
        if (null == oneByContentAndBoardSize) {
            log.error("找不到预置发布的信息");
            return;
        }

        // 获取同类型最新的一条发布记录
        ReleaseRecord oneLatestByBoardId = releaseRecordService.getOneLatestByBoardId(oneByIP.getBoardIp(), 1);
        if (null == oneLatestByBoardId) {
            // 说明之前没有发布记录
        }

//         todo 发布
        boolean sanSiProtocol = new SanSiProtocol().publishContent(oneByIP, oneByContentAndBoardSize);
        // 经过主动发布之后就变成预置信息
        // 发布之后记录发布内容 ReleaseRecord
        ReleaseRecord releaseRecord = new ReleaseRecord();
        releaseRecord.setBoardId(oneByIP.getId());
        releaseRecord.setPresetContentId(oneByContentAndBoardSize.getId());
        releaseRecord.setCreateTime(new Date());
        releaseRecord.setCreatedBy(SecurityUtils.getUserId().intValue());
        releaseRecordService.save(releaseRecord);
        // 记录完了之后就需要向对方发送日志记录
        WarningStatusInfo statusInfo = new WarningStatusInfo();
        statusInfo.setStatus("");
        statusInfo.setInfoBoardIP(oneByIP.getBoardIp());
        statusInfo.setWarningType(params.getPerceptionType());
        statusInfo.setWarningMessage(oneByContentAndBoardSize.getContent());
        statusInfo.setWarningValue(params.getPerceptionValue());
        statusInfo.setCurrentWarningLevel(oneByTypeAndValue.getLevel());
        statusInfo.setTriggerTime(new Date());
        // 开始发送状态记录
        MerchantsHttp.sendWarning(new WarningStatusInfo());
    }
}
